@@ -1,13 +1,14 @@
-use 5.14.0;
+use 5.10.1;
 use strict;
 use warnings;
 
 package Pod::Elemental::Transformer::Splint;
 
-our $VERSION = '0.1100'; # VERSION
+our $VERSION = '0.1200'; # VERSION
 # ABSTRACT: Documentation from class metadata
 
 use Moose;
+use namespace::autoclean;
 use Path::Tiny;
 use Safe::Isa;
 use Try::Tiny;
@@ -394,6 +395,8 @@ sub is_text {
     return $attr->has_write_method ? 'read/write' : 'read-only';
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -410,20 +413,20 @@ Pod::Elemental::Transformer::Splint - Documentation from class metadata
 
 =begin HTML
 
-<p><img src="https://img.shields.io/badge/perl-5.14+-brightgreen.svg" alt="Requires Perl 5.14+" /> <a href="https://travis-ci.org/Csson/p5-Pod-Elemental-Transformer-Splint"><img src="https://api.travis-ci.org/Csson/p5-Pod-Elemental-Transformer-Splint.svg?branch=master" alt="Travis status" /></a></p>
+<p><img src="https://img.shields.io/badge/perl-5.10.1+-brightgreen.svg" alt="Requires Perl 5.10.1+" /> <a href="https://travis-ci.org/Csson/p5-Pod-Elemental-Transformer-Splint"><img src="https://api.travis-ci.org/Csson/p5-Pod-Elemental-Transformer-Splint.svg?branch=master" alt="Travis status" /></a> <img src="https://img.shields.io/badge/coverage-81.3%-orange.svg" alt="coverage 81.3%" /></p>
 
 =end HTML
 
 
 =begin markdown
 
-![Requires Perl 5.14+](https://img.shields.io/badge/perl-5.14+-brightgreen.svg) [![Travis status](https://api.travis-ci.org/Csson/p5-Pod-Elemental-Transformer-Splint.svg?branch=master)](https://travis-ci.org/Csson/p5-Pod-Elemental-Transformer-Splint)
+![Requires Perl 5.10.1+](https://img.shields.io/badge/perl-5.10.1+-brightgreen.svg) [![Travis status](https://api.travis-ci.org/Csson/p5-Pod-Elemental-Transformer-Splint.svg?branch=master)](https://travis-ci.org/Csson/p5-Pod-Elemental-Transformer-Splint) ![coverage 81.3%](https://img.shields.io/badge/coverage-81.3%-orange.svg)
 
 =end markdown
 
 =head1 VERSION
 
-Version 0.1100, released 2016-01-12.
+Version 0.1200, released 2016-02-02.
 
 =head1 SYNOPSIS
 
