@@ -1,13 +1,14 @@
-use 5.14.0;
+use 5.10.1;
 use strict;
 use warnings;
 
 package Pod::Elemental::Transformer::Splint::AttributeRenderer::HtmlDefault;
 
-our $VERSION = '0.1100'; # VERSION
+our $VERSION = '0.1200'; # VERSION
 # ABSTRACT: Default html attribute renderer
 
 use Moose;
+use namespace::autoclean;
 use Path::Tiny;
 use Pod::Simple::XHTML;
 use syntax 'qs';
@@ -129,6 +130,8 @@ sub make_cell_without_border_right_aligned {
     return qq{    <td style="text-align: right; padding-right: 6px; padding-left: 6px;$nowrap">$text</td>};
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -143,7 +146,7 @@ Pod::Elemental::Transformer::Splint::AttributeRenderer::HtmlDefault - Default ht
 
 =head1 VERSION
 
-Version 0.1100, released 2016-01-12.
+Version 0.1200, released 2016-02-02.
 
 =head1 SOURCE
 
